Module cargo

Module cargo 

Provides a wrapper around cargo environment variables set during compilation.

The available environment variables can be found here

Structs

CargoEnv
Provides access to cargo environment variables. Getting an instance of this struct guarantees the existence of cargo related variables

Functions

get_cargo_env
Gets the cargo environment if available