pub trait IntoProvider<T>{
type Provider: Provider<T>;
// Required method
fn into_provider(self) -> Self::Provider;
}Expand description
Represents that a type can be represented as a provider. All Providers implement this trait.
pub trait IntoProvider<T>{
type Provider: Provider<T>;
// Required method
fn into_provider(self) -> Self::Provider;
}Represents that a type can be represented as a provider. All Providers implement this trait.