UpToDate

Trait UpToDate 

pub trait UpToDate {
    // Provided method
    fn up_to_date(&self) -> bool { ... }
}
Can check if this value is up to date.

Provided Methods

fn up_to_date(&self) -> bool

Whether this value is up to date.

By default, everything is always not up to date.

Implementors

Source

impl UpToDate for Help

Source

impl UpToDate for TaskReport

Source

impl UpToDate for assemble_std::defaults::tasks::WrapperTask

Source

impl UpToDate for Empty

Source

impl UpToDate for DownloadFile

Source

impl UpToDate for assemble_std::tasks::wrapper::WrapperTask

Source

impl UpToDate for Output

Source

impl<'h, T> UpToDate for UpToDateHandler<'h, T>
where T: Task,

Source

impl<T> UpToDate for Basic<T>
where T: Debug,

Source

impl<T> UpToDate for TaskHandle<T>
where T: Task + Send + Sync + Debug + 'static,