Lazy evaluation allows for a more simple approach to sharing data between tasks.
The main driving trait that allows for this is Provider. Objects that
implement this trait can try to provide a value of that type. There are three main flavors
of providers.
Properties
Prop<T> - A property that can be set to a specific value.
Usage
Should be used when single values are needed, and this property is needed to either be used
as an output that’s set by the task, or the task needs an input. When used with the
CreateTask derive macro.
struct LogTask {
msg: Prop<String>
}Modules
Structs
- AnyProp
- A property that contains a value. Once a property is created, only types that use the correct type are used.
- Prop
- A typed prop
- Provider
Error - A value could not be provided
- VecProp
- A vec prop is a special property that uses a list
Enums
Traits
- Into
Provider - Represents that a type can be represented as a provider. All Providers implement this trait.
- Provider
- The provider trait represents an object that can continuously produce a value. Provider values
can be chained together using the
ProviderExttrait. - Provider
Ext - Provides extensions that are not object safe to the Provider trait.