pub trait UpToDate {
// Provided method
fn up_to_date(&self) -> bool { ... }
}Expand description
Can check if this value is up to date.
Provided Methods
Sourcefn up_to_date(&self) -> bool
fn up_to_date(&self) -> bool
Whether this value is up to date.
By default, everything is always not up to date.